CustomElement class

ElementName : "" ElementNameSpace : "" ChildElement : "" ChildBody : ""

Constructors

CustomElement({String? elementName, String? elementNameSpace, String? childElement, String? childBody})
CustomElement.fromJson(dynamic json)

Properties

childBody → String?
no setter
childElement → String?
no setter
elementName → String?
no setter
elementNameSpace → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited